.. currentmodule:: pyfits

*****
Cards
*****

.. inheritance-diagram:: Card RecordValuedKeywordCard
   :parts: 2

`Card`
======

.. autoclass:: Card
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`RecordValuedKeywordCard`
=========================

.. autoclass:: RecordValuedKeywordCard
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

Free functions
==============

create_card
-----------

.. autofunction:: create_card

create_card_from_string
-----------------------

.. autofunction:: create_card_from_string

upper_key
---------

.. autofunction:: upper_key

